@@ -6,10 +6,10 @@ use std::{
 };
 
 const ELEMENT_SIZE: usize = mem::size_of::<usize>() * 8;
-const TOTAL_BITS: u64 = 8192;
+const TOTAL_BITS: u64 = 8_192;
 const ELEMENT_COUNT: usize = (TOTAL_BITS / ELEMENT_SIZE as u64) as usize;
 
-/// Experimental struct for now, a bitmap 1KB long, or containing 8192 bits.
+/// Experimental struct for now, a bitmap containing 8_192 bits.
 /// I wouldn't yet recommend using this struct until it's more stable!
 #[derive(PartialEq, Eq, PartialOrd, Ord, Clone, Copy, Hash, Debug)]
 pub struct BitmapKB([usize; ELEMENT_COUNT]);
@@ -308,7 +308,7 @@ mod tests {
     #[test]
     fn create_default() {
         let bitmap = BitmapKB::default();
-        assert_eq!([0; 128], *bitmap);
+        assert_eq!([0; ELEMENT_COUNT], *bitmap);
     }
 
     #[test]
